#[non_exhaustive]pub struct Registration {
pub id: String,
pub url: Option<String>,
pub as_token: String,
pub hs_token: String,
pub sender_localpart: String,
pub namespaces: Namespaces,
pub rate_limited: Option<bool>,
pub protocols: Option<Vec<String>>,
pub receive_ephemeral: bool,
}api and (crate features appservice-api-c or appservice-api-s) only.Expand description
Information required in the registration yaml file that a homeserver needs.
To create an instance of this type, first create a RegistrationInit and convert it via
Registration::from / .into().
Used for appservice registration.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringA unique, user - defined ID of the application service which will never change.
url: Option<String>The URL for the application service.
Optionally set to null if no traffic is required.
as_token: StringA unique token for application services to use to authenticate requests to Homeservers.
hs_token: StringA unique token for Homeservers to use to authenticate requests to application services.
sender_localpart: StringThe localpart of the user associated with the application service.
namespaces: NamespacesA list of users, aliases and rooms namespaces that the application service controls.
rate_limited: Option<bool>Whether requests from masqueraded users are rate-limited.
The sender is excluded.
protocols: Option<Vec<String>>The external protocols which the application service provides (e.g. IRC).
receive_ephemeral: boolWhether the application service wants to receive ephemeral data.
Defaults to false.